from __future__ import absolute_import

from SSML.Google import Google
from SSML.Exceptions import *


__description__ = "Python library to generate SSML for voice Assistant"
__version__ = "1.0.5"
